import fs from 'fs';
import path from 'path';
import { defineConfig } from 'vite';
import react from '@vitejs/plugin-react';

const { appName } = require('./package.json');

const port = 3000;

export default defineConfig({
  resolve: {
    alias: [
      {
        find: '@',
        replacement: path.resolve(process.cwd(), '/src'),
      },
    ],
  },
  define: {
    'NODE_ENV': JSON.stringify(process.env.NODE_ENV),
    'APP_NAME': JSON.stringify(appName),
  },
  plugins: [
    react(),
  ],
  server: {
    port,
    open: `http://localhost:${port}/`, // 或 true
  },
  // 解决在 js 文件里写 jsx
  // How to use .js instead of .jsx https://github.com/vitejs/vite/discussions/3448
  esbuild: {
    loader: 'jsx',
    include: /src\/.*\.jsx?$/,
    // loader: 'tsx',
    // include: /src\/.*\.[tj]sx?$/,
    exclude: [],
  },
  optimizeDeps: {
    esbuildOptions: {
      plugins: [
        {
          name: 'load-js-files-as-jsx',
          setup(build) {
            build.onLoad({ filter: /src\/.*\.js$/ }, async (args) => ({
              loader: 'jsx',
              contents: fs.readFileSync(args.path, 'utf8'),
            }));
          },
        },
      ],
    },
  },
});