import fs from 'fs';
import path from 'path';
import { defineConfig } from 'vite';
import react from '@vitejs/plugin-react';
import vitePluginQiankun from 'vite-plugin-qiankun';

const { appName } = require('./package.json');

const isDev = process.env.NODE_ENV === 'development';

const basename = `/micro/${appName}`;

const port = 3002;

const htmlRemoveFreshPlugin = () => {
  return {
    name: 'html-transform',
    transformIndexHtml(html) {
      const $ = require('cheerio').load(html);
      $('script').eq(0).remove();
      // $('head').prepend(
      // `<script>
      // import((window.proxy ? (window.proxy.__INJECTED_PUBLIC_PATH_BY_QIANKUN__ + '..') : '') + '/@react-refresh').then(({ default: RefreshRuntime }) => {    
      //   RefreshRuntime.injectIntoGlobalHook(window)
      //   window.$RefreshReg$ = () => {}
      //   window.$RefreshSig$ = () => (type) => type
      //   window.__vite_plugin_react_preamble_installed__ = true
      // })
      // </script>`);
      html = $.html();
      return html;
    },
  };
};

export default defineConfig({
  base: `http://localhost:${port}`,
  resolve: {
    alias: [
      {
        find: '@',
        replacement: path.resolve(process.cwd(), '/src'),
      },
    ],
  },
  define: {
    'process.env.BASENAME': JSON.stringify(basename),
  },
  plugins: [
    react(),
    vitePluginQiankun(appName, { useDevMode: true }),
    ...(isDev ? 
      [htmlRemoveFreshPlugin()]
      : []),
  ],
  server: {
    port,
    origin: `http://localhost:${port}`,
    open: `http://localhost:${port}${basename}/`, // 或 true
  },
  // 解决在 js 文件里写 jsx
  // How to use .js instead of .jsx https://github.com/vitejs/vite/discussions/3448
  esbuild: {
    loader: 'jsx',
    include: /src\/.*\.jsx?$/,
    // loader: 'tsx',
    // include: /src\/.*\.[tj]sx?$/,
    exclude: [],
  },
  optimizeDeps: {
    esbuildOptions: {
      plugins: [
        {
          name: 'load-js-files-as-jsx',
          setup(build) {
            build.onLoad({ filter: /src\/.*\.js$/ }, async (args) => ({
              loader: 'jsx',
              contents: fs.readFileSync(args.path, 'utf8'),
            }));
          },
        },
      ],
    },
  },
});